__version__ = "0.2.0"
from .dmat             import DMAT
from .dis              import DIS
from .dis_ei           import DIS_EI
from .plot_2d          import plot_2d
from .plot_3d          import plot_3d
from .extend_plots     import extend_plots
from .append_plots     import append_plots
from .symbolic_BSpline import symbolic_BSpline
from .Minimize         import Minimize
from .num_int          import num_int
from .plot_param_grid  import plot_param_grid